1.  Add rebalance rule to portfolio
2.  Add currency to add_symbol function
3.  Add timer
4.  Additional order types:
      a.  stop trail limit (trigger price updated as current market price changes).
      b.  market and limit on close
5.  Add ability to use Bid / Offer data instead of OHLC
6.  Benchmarks - Return and Correlation
7.  Commissions & Fees
      a.  Fixed commision per future or stock
      b.  Per ticket fees
      c.  Short interest
      d.  ETF Fees 
8.  Dynamically selecting universe of symbols
9.  Single dimension optimization
10.  Trade metrics
11.  Max adverse excursion
12.  Monte Carlo
13.  Option Expiry ??
